@@ -1,14 +1,12 @@
-
-__version__ = "0.1.1"
-
 from kokki import cookbook
 from kokki.base import *
 from kokki.cookbook import *
 from kokki.environment import *
-from kokki.packaging import *
 from kokki.providers import *
 from kokki.recipe import *
+from kokki.resources import *
 from kokki.runner import *
-from kokki.service import *
 from kokki.source import *
-from kokki.system import *
+from kokki.version import *
+
+__version__ = VERSION
